@@ -18,21 +18,47 @@ use fields qw/
 	  over_18 parent_id replies body body_html
 	  user_reports mod_reports
 	  link_author link_id link_permalink link_title link_url 
+	  more
 /;
 
 use constant type => "t1";
-
-sub set_replies {
+# This is called by the magic in Thing.pm on creation
+sub set_replies { 
     my ($self, $value) = @_;
     if (ref $value && exists $value->{data}{children}) {
-	    $self->{replies} = [ map { Reddit::Client::Comment->new($self->{session}, $_->{data}) } @{$value->{data}{children}} ];
+		my $comments = $value->{data}{children};
+		my $return = [];
+
+		for my $cmt (@$comments) {
+			# 'kind' is on same level as 'data'
+			if ($cmt->{kind} eq 't1') {
+				push @$return, Reddit::Client::Comment->new($self->{session}, $cmt->{data});
+			} elsif ($cmt->{kind} eq 'more') {
+				my $more = Reddit::Client::MoreComments->new($self->{session}, $cmt->{data});
+				$more->{link_id} = $self->{link_id};
+				$self->{more} = $more->{children};
+				push @$return, $more;
+			}
+		}
+		
+		$self->{replies} = $return;
     } else {
         $self->{replies} = [];
     }
 }
+# need fix this
+sub get_collapsed_comments {
+	my ($self, %param) = @_;
+	return undef if !$self->{more} or ref $self->{more} ne 'ARRAY';
+	
+	my %data = (
+		link_id		=> $self->{link_id},
+		children	=> $self->{more},
+	);
+	$data{sort}	= $param{sort} if $param{sort};
+	$data{id}	= $param{id} if $param{id};
 
-sub replies {
-    return shift->{replies};
+	return $self->{session}->get_collapsed_comments( %data );
 }
 
 sub reply {
@@ -61,15 +87,35 @@ sub delete {
 	my $cmtid = $self->{session}->delete($self->{name});
 	return $cmtid;
 }
-# The API return a 'permalink' that starts at '/r/sub..'
-# This just prepends the rest of the address
-sub get_permalink {
+sub get_permalink { 	# deprecated. Duplicated instead of calling get_web_url
+	my $self = shift;	# because this may (and probably will) change someday
+	return $self->{session}->get_origin().$self->{permalink}
+}
+sub get_web_url {
 	my $self = shift;
-	my $parentid = substr $self->{link_id}, 3;
-
-	return sprintf "%s/r/$self->{subreddit}/comments/%s//%s", $self->{session}->LINK_URL, $parentid, $self->{id};
+	return $self->{session}->get_origin().$self->{permalink}
+}
+sub get_children {
+	my $self = shift;
+	my $cmts = $self->{session}->get_comments(permalink=>$self->{permalink});
+	$self->{replies} = $$cmts[0]->{replies}; # populate this comment's replies
+	return $$cmts[0]->{replies}; 
+}
+sub get_comments {
+	my $self = shift;
+	my $cmts = $self->{session}->get_comments(permalink=>$self->{permalink});
+	$self->{replies} = $$cmts[0]->{replies}; # populate this comment's replies
+	return $cmts;
 }
 
+sub has_collapsed_children {
+	my $self = shift;
+	return $self->{more} ? 1 : 0;
+}
+
+sub replies {
+    return shift->{replies};
+}
 1;
 
 __END__
